@@ -1,14 +1,14 @@
 context("set attributes")
 
 test_that("only valid types can be passed to functions", {
-  expect_error(create_trajectory() %>% set_attribute("test", "string_value"))
-  expect_error(create_trajectory() %>% set_attribute("test", 3), NA)
-  expect_error(create_trajectory() %>% set_attribute("test", function() 3), NA)
+  expect_error(trajectory() %>% set_attribute("test", "string_value"))
+  expect_error(trajectory() %>% set_attribute("test", 3), NA)
+  expect_error(trajectory() %>% set_attribute("test", function() 3), NA)
 
 })
 
 test_that("an arrival attribute is correctly set and returned to a function", {
-  t0 <- create_trajectory() %>%
+  t0 <- trajectory() %>%
     set_attribute("test", 123) %>%
     set_attribute("test", 456, global = TRUE) %>%
     log_(function(attrs) paste0(attrs["test"])) %>%
@@ -24,7 +24,7 @@ test_that("an arrival attribute is correctly set and returned to a function", {
 })
 
 test_that("attributes can be correctly retrieved using get_mon_attributes()", {
-  t0 <- create_trajectory() %>%
+  t0 <- trajectory() %>%
     set_attribute("test", function() 123) %>%
     set_attribute("test", function() 456, global = TRUE)
 
@@ -45,7 +45,7 @@ test_that("attributes can be correctly retrieved using get_mon_attributes()", {
 })
 
 test_that("the attribute dataframe is returned with the expected columns", {
-  t0 <- create_trajectory() %>%
+  t0 <- trajectory() %>%
     set_attribute("test", 123) %>%
     set_attribute("test", 456, global = TRUE)
 
@@ -61,7 +61,7 @@ test_that("the attribute dataframe is returned with the expected columns", {
 
 
 test_that("arrival attributes are returned empty when mon level is <2", {
-  t0 <- create_trajectory() %>%
+  t0 <- trajectory() %>%
     set_attribute("test", 123) %>%
     set_attribute("test", 456, global = TRUE)
 
